
.. _hal_api:

HAL API
-------

The WPILib Hardware Abstraction Layer (HAL) is used by WPILib to interact
with robot devices in a platform independent way.

Generally, RobotPy users should avoid interacting with the HAL directly.

.. note:: Previously there were useful HAL simulation components in the
          ``hal.simulation`` package. They have been moved to 
          ``wpilib.simulation`` instead.

.. toctree::

  hal
  hal.simulation